==> s2n-tls-sys-0.0.2.crate: s2n-tls-sys-0.0.2/files.rs <==

// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0

[
    "lib/crypto/s2n_aead_cipher_aes_gcm.c",
    "lib/crypto/s2n_aead_cipher_chacha20_poly1305.c",
    "lib/crypto/s2n_cbc_cipher_3des.c",
    "lib/crypto/s2n_cbc_cipher_aes.c",
    "lib/crypto/s2n_certificate.c",
    "lib/crypto/s2n_cipher.c",
    "lib/crypto/s2n_composite_cipher_aes_sha.c",
    "lib/crypto/s2n_crypto.c",
    "lib/crypto/s2n_dhe.c",
    "lib/crypto/s2n_drbg.c",
    "lib/crypto/s2n_ecc_evp.c",
    "lib/crypto/s2n_ecdsa.c",
    "lib/crypto/s2n_evp.c",
    "lib/crypto/s2n_evp_signing.c",
    "lib/crypto/s2n_fips.c",
    "lib/crypto/s2n_hash.c",
    "lib/crypto/s2n_hkdf.c",
    "lib/crypto/s2n_hmac.c",
    "lib/crypto/s2n_libcrypto.c",
    "lib/crypto/s2n_openssl_x509.c",
    "lib/crypto/s2n_pkey.c",
    "lib/crypto/s2n_rsa.c",
    "lib/crypto/s2n_rsa_pss.c",
    "lib/crypto/s2n_rsa_signing.c",
    "lib/crypto/s2n_sequence.c",
    "lib/crypto/s2n_stream_cipher_null.c",
    "lib/crypto/s2n_stream_cipher_rc4.c",
    "lib/crypto/s2n_tls13_keys.c",
    "lib/error/s2n_errno.c",
    "lib/pq-crypto/bike_r1/aes_ctr_prf.c",
    "lib/pq-crypto/bike_r1/bike_r1_kem.c",
    "lib/pq-crypto/bike_r1/converts_portable.c",
    "lib/pq-crypto/bike_r1/decode.c",
    "lib/pq-crypto/bike_r1/error.c",
    "lib/pq-crypto/bike_r1/gf2x_mul.c",
    "lib/pq-crypto/bike_r1/gf2x_portable.c",
    "lib/pq-crypto/bike_r1/openssl_utils.c",
    "lib/pq-crypto/bike_r1/parallel_hash.c",
    "lib/pq-crypto/bike_r1/sampling.c",
    "lib/pq-crypto/bike_r1/sampling_portable.c",
    "lib/pq-crypto/bike_r1/secure_decode_portable.c",
    "lib/pq-crypto/bike_r1/utilities.c",
    "lib/pq-crypto/bike_r2/aes_ctr_prf.c",
    "lib/pq-crypto/bike_r2/bike_r2_kem.c",
    "lib/pq-crypto/bike_r2/decode.c",
    "lib/pq-crypto/bike_r2/error.c",
    "lib/pq-crypto/bike_r2/gf2x_mul.c",
    "lib/pq-crypto/bike_r2/gf2x_portable.c",
    "lib/pq-crypto/bike_r2/openssl_utils.c",
    "lib/pq-crypto/bike_r2/sampling.c",
    "lib/pq-crypto/bike_r2/sampling_portable.c",
    "lib/pq-crypto/bike_r2/secure_decode_portable.c",
    "lib/pq-crypto/bike_r2/utilities.c",
    "lib/pq-crypto/bike_r3/aes_ctr_prf.c",
    "lib/pq-crypto/bike_r3/bike_r3_kem.c",
    "lib/pq-crypto/bike_r3/decode.c",
    "lib/pq-crypto/bike_r3/decode_avx2.c",
    "lib/pq-crypto/bike_r3/decode_avx512.c",
    "lib/pq-crypto/bike_r3/decode_portable.c",
    "lib/pq-crypto/bike_r3/error.c",
    "lib/pq-crypto/bike_r3/gf2x_inv.c",
    "lib/pq-crypto/bike_r3/gf2x_ksqr_avx2.c",
    "lib/pq-crypto/bike_r3/gf2x_ksqr_avx512.c",
    "lib/pq-crypto/bike_r3/gf2x_ksqr_portable.c",
    "lib/pq-crypto/bike_r3/gf2x_mul.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_avx2.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_avx512.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_base_pclmul.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_base_portable.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_base_vpclmul.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_portable.c",
    "lib/pq-crypto/bike_r3/sampling.c",
    "lib/pq-crypto/bike_r3/sampling_avx2.c",
    "lib/pq-crypto/bike_r3/sampling_avx512.c",
    "lib/pq-crypto/bike_r3/sampling_portable.c",
    "lib/pq-crypto/bike_r3/utilities.c",
    "lib/pq-crypto/kyber_90s_r2/aes256ctr.c",
    "lib/pq-crypto/kyber_90s_r2/aes_c.c",
    "lib/pq-crypto/kyber_90s_r2/cbd.c",
    "lib/pq-crypto/kyber_90s_r2/indcpa.c",
    "lib/pq-crypto/kyber_90s_r2/kyber_90s_r2_kem.c",
    "lib/pq-crypto/kyber_90s_r2/ntt.c",
    "lib/pq-crypto/kyber_90s_r2/poly.c",
    "lib/pq-crypto/kyber_90s_r2/polyvec.c",
    "lib/pq-crypto/kyber_90s_r2/reduce.c",
    "lib/pq-crypto/kyber_90s_r2/sha2_c.c",
    "lib/pq-crypto/kyber_90s_r2/verify.c",
    "lib/pq-crypto/kyber_r2/cbd.c",
    "lib/pq-crypto/kyber_r2/fips202_kyber_r2.c",
    "lib/pq-crypto/kyber_r2/indcpa.c",
    "lib/pq-crypto/kyber_r2/kyber_r2_kem.c",
    "lib/pq-crypto/kyber_r2/ntt.c",
    "lib/pq-crypto/kyber_r2/poly.c",
    "lib/pq-crypto/kyber_r2/polyvec.c",
    "lib/pq-crypto/kyber_r2/reduce.c",
    "lib/pq-crypto/kyber_r2/symmetric-fips202.c",
    "lib/pq-crypto/kyber_r2/verify.c",
    "lib/pq-crypto/kyber_r3/KeccakP-1600-times4-SIMD256_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_cbd.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_cbd_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_consts_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_fips202.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_fips202x4_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_indcpa.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_indcpa_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_kem.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_ntt.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_poly.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_poly_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_polyvec.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_polyvec_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_reduce.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_rejsample_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_symmetric-shake.c",
    "lib/pq-crypto/s2n_pq.c",
    "lib/pq-crypto/s2n_pq_random.c",
    "lib/pq-crypto/sike_r1/P503_r1.c",
    "lib/pq-crypto/sike_r1/ec_isogeny_r1.c",
    "lib/pq-crypto/sike_r1/fips202_r1.c",
    "lib/pq-crypto/sike_r1/fp_generic_r1.c",
    "lib/pq-crypto/sike_r1/fpx_r1.c",
    "lib/pq-crypto/sike_r1/sidh_r1.c",
    "lib/pq-crypto/sike_r1/sike_r1_kem.c",
    "lib/pq-crypto/sike_r3/sikep434r3.c",
    "lib/pq-crypto/sike_r3/sikep434r3_ec_isogeny.c",
    "lib/pq-crypto/sike_r3/sikep434r3_fips202.c",
    "lib/pq-crypto/sike_r3/sikep434r3_fp.c",
    "lib/pq-crypto/sike_r3/sikep434r3_fpx.c",
    "lib/pq-crypto/sike_r3/sikep434r3_kem.c",
    "lib/pq-crypto/sike_r3/sikep434r3_sidh.c",
    "lib/stuffer/s2n_stuffer.c",
    "lib/stuffer/s2n_stuffer_base64.c",
    "lib/stuffer/s2n_stuffer_file.c",
    "lib/stuffer/s2n_stuffer_network_order.c",
    "lib/stuffer/s2n_stuffer_pem.c",
    "lib/stuffer/s2n_stuffer_text.c",
    "lib/tls/extensions/s2n_client_alpn.c",
    "lib/tls/extensions/s2n_client_early_data_indication.c",
    "lib/tls/extensions/s2n_client_ems.c",
    "lib/tls/extensions/s2n_client_key_share.c",
    "lib/tls/extensions/s2n_client_max_frag_len.c",
    "lib/tls/extensions/s2n_client_pq_kem.c",
    "lib/tls/extensions/s2n_client_psk.c",
    "lib/tls/extensions/s2n_client_renegotiation_info.c",
    "lib/tls/extensions/s2n_client_sct_list.c",
    "lib/tls/extensions/s2n_client_server_name.c",
    "lib/tls/extensions/s2n_client_session_ticket.c",
    "lib/tls/extensions/s2n_client_signature_algorithms.c",
    "lib/tls/extensions/s2n_client_status_request.c",
    "lib/tls/extensions/s2n_client_supported_groups.c",
    "lib/tls/extensions/s2n_client_supported_versions.c",
    "lib/tls/extensions/s2n_cookie.c",
    "lib/tls/extensions/s2n_ec_point_format.c",
    "lib/tls/extensions/s2n_extension_list.c",
    "lib/tls/extensions/s2n_extension_type.c",
    "lib/tls/extensions/s2n_extension_type_lists.c",
    "lib/tls/extensions/s2n_key_share.c",
    "lib/tls/extensions/s2n_nst_early_data_indication.c",
    "lib/tls/extensions/s2n_psk_key_exchange_modes.c",
    "lib/tls/extensions/s2n_quic_transport_params.c",
    "lib/tls/extensions/s2n_server_alpn.c",
    "lib/tls/extensions/s2n_server_certificate_status.c",
    "lib/tls/extensions/s2n_server_early_data_indication.c",
    "lib/tls/extensions/s2n_server_ems.c",
    "lib/tls/extensions/s2n_server_key_share.c",
    "lib/tls/extensions/s2n_server_max_fragment_length.c",
    "lib/tls/extensions/s2n_server_psk.c",
    "lib/tls/extensions/s2n_server_renegotiation_info.c",
    "lib/tls/extensions/s2n_server_sct_list.c",
    "lib/tls/extensions/s2n_server_server_name.c",
    "lib/tls/extensions/s2n_server_session_ticket.c",
    "lib/tls/extensions/s2n_server_signature_algorithms.c",
    "lib/tls/extensions/s2n_server_status_request.c",
    "lib/tls/extensions/s2n_server_supported_versions.c",
    "lib/tls/extensions/s2n_supported_versions.c",
    "lib/tls/s2n_aead.c",
    "lib/tls/s2n_alerts.c",
    "lib/tls/s2n_async_pkey.c",
    "lib/tls/s2n_auth_selection.c",
    "lib/tls/s2n_cbc.c",
    "lib/tls/s2n_change_cipher_spec.c",
    "lib/tls/s2n_cipher_preferences.c",
    "lib/tls/s2n_cipher_suites.c",
    "lib/tls/s2n_client_cert.c",
    "lib/tls/s2n_client_cert_verify.c",
    "lib/tls/s2n_client_finished.c",
    "lib/tls/s2n_client_hello.c",
    "lib/tls/s2n_client_hello_request.c",
    "lib/tls/s2n_client_key_exchange.c",
    "lib/tls/s2n_config.c",
    "lib/tls/s2n_connection.c",
    "lib/tls/s2n_connection_evp_digests.c",
    "lib/tls/s2n_early_data.c",
    "lib/tls/s2n_early_data_io.c",
    "lib/tls/s2n_ecc_preferences.c",
    "lib/tls/s2n_encrypted_extensions.c",
    "lib/tls/s2n_establish_session.c",
    "lib/tls/s2n_handshake.c",
    "lib/tls/s2n_handshake_hashes.c",
    "lib/tls/s2n_handshake_io.c",
    "lib/tls/s2n_handshake_transcript.c",
    "lib/tls/s2n_handshake_type.c",
    "lib/tls/s2n_kem.c",
    "lib/tls/s2n_kem_preferences.c",
    "lib/tls/s2n_kex.c",
    "lib/tls/s2n_key_log.c",
    "lib/tls/s2n_key_update.c",
    "lib/tls/s2n_ocsp_stapling.c",
    "lib/tls/s2n_post_handshake.c",
    "lib/tls/s2n_prf.c",
    "lib/tls/s2n_protocol_preferences.c",
    "lib/tls/s2n_psk.c",
    "lib/tls/s2n_quic_support.c",
    "lib/tls/s2n_record_read.c",
    "lib/tls/s2n_record_read_aead.c",
    "lib/tls/s2n_record_read_cbc.c",
    "lib/tls/s2n_record_read_composite.c",
    "lib/tls/s2n_record_read_stream.c",
    "lib/tls/s2n_record_write.c",
    "lib/tls/s2n_recv.c",
    "lib/tls/s2n_resume.c",
    "lib/tls/s2n_security_policies.c",
    "lib/tls/s2n_send.c",
    "lib/tls/s2n_server_cert.c",
    "lib/tls/s2n_server_cert_request.c",
    "lib/tls/s2n_server_done.c",
    "lib/tls/s2n_server_extensions.c",
    "lib/tls/s2n_server_finished.c",
    "lib/tls/s2n_server_hello.c",
    "lib/tls/s2n_server_hello_retry.c",
    "lib/tls/s2n_server_key_exchange.c",
    "lib/tls/s2n_server_new_session_ticket.c",
    "lib/tls/s2n_shutdown.c",
    "lib/tls/s2n_signature_algorithms.c",
    "lib/tls/s2n_signature_scheme.c",
    "lib/tls/s2n_tls.c",
    "lib/tls/s2n_tls13.c",
    "lib/tls/s2n_tls13_certificate_verify.c",
    "lib/tls/s2n_tls13_handshake.c",
    "lib/tls/s2n_x509_validator.c",
    "lib/utils/s2n_array.c",
    "lib/utils/s2n_asn1_time.c",
    "lib/utils/s2n_blob.c",
    "lib/utils/s2n_ensure.c",
    "lib/utils/s2n_init.c",
    "lib/utils/s2n_map.c",
    "lib/utils/s2n_mem.c",
    "lib/utils/s2n_random.c",
    "lib/utils/s2n_result.c",
    "lib/utils/s2n_rfc5952.c",
    "lib/utils/s2n_safety.c",
    "lib/utils/s2n_set.c",
    "lib/utils/s2n_socket.c",
    "lib/utils/s2n_str.c",
    "lib/utils/s2n_timer.c",
]

==> s2n-tls-sys-0.0.6.crate: s2n-tls-sys-0.0.6/files.rs <==

// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0

[
    "lib/crypto/s2n_aead_cipher_aes_gcm.c",
    "lib/crypto/s2n_aead_cipher_chacha20_poly1305.c",
    "lib/crypto/s2n_cbc_cipher_3des.c",
    "lib/crypto/s2n_cbc_cipher_aes.c",
    "lib/crypto/s2n_certificate.c",
    "lib/crypto/s2n_cipher.c",
    "lib/crypto/s2n_composite_cipher_aes_sha.c",
    "lib/crypto/s2n_crypto.c",
    "lib/crypto/s2n_dhe.c",
    "lib/crypto/s2n_drbg.c",
    "lib/crypto/s2n_ecc_evp.c",
    "lib/crypto/s2n_ecdsa.c",
    "lib/crypto/s2n_evp.c",
    "lib/crypto/s2n_evp_signing.c",
    "lib/crypto/s2n_fips.c",
    "lib/crypto/s2n_hash.c",
    "lib/crypto/s2n_hkdf.c",
    "lib/crypto/s2n_hmac.c",
    "lib/crypto/s2n_libcrypto.c",
    "lib/crypto/s2n_openssl_x509.c",
    "lib/crypto/s2n_pkey.c",
    "lib/crypto/s2n_rsa.c",
    "lib/crypto/s2n_rsa_pss.c",
    "lib/crypto/s2n_rsa_signing.c",
    "lib/crypto/s2n_sequence.c",
    "lib/crypto/s2n_stream_cipher_null.c",
    "lib/crypto/s2n_stream_cipher_rc4.c",
    "lib/crypto/s2n_tls13_keys.c",
    "lib/error/s2n_errno.c",
    "lib/pq-crypto/bike_r1/aes_ctr_prf.c",
    "lib/pq-crypto/bike_r1/bike_r1_kem.c",
    "lib/pq-crypto/bike_r1/converts_portable.c",
    "lib/pq-crypto/bike_r1/decode.c",
    "lib/pq-crypto/bike_r1/error.c",
    "lib/pq-crypto/bike_r1/gf2x_mul.c",
    "lib/pq-crypto/bike_r1/gf2x_portable.c",
    "lib/pq-crypto/bike_r1/openssl_utils.c",
    "lib/pq-crypto/bike_r1/parallel_hash.c",
    "lib/pq-crypto/bike_r1/sampling.c",
    "lib/pq-crypto/bike_r1/sampling_portable.c",
    "lib/pq-crypto/bike_r1/secure_decode_portable.c",
    "lib/pq-crypto/bike_r1/utilities.c",
    "lib/pq-crypto/bike_r2/aes_ctr_prf.c",
    "lib/pq-crypto/bike_r2/bike_r2_kem.c",
    "lib/pq-crypto/bike_r2/decode.c",
    "lib/pq-crypto/bike_r2/error.c",
    "lib/pq-crypto/bike_r2/gf2x_mul.c",
    "lib/pq-crypto/bike_r2/gf2x_portable.c",
    "lib/pq-crypto/bike_r2/openssl_utils.c",
    "lib/pq-crypto/bike_r2/sampling.c",
    "lib/pq-crypto/bike_r2/sampling_portable.c",
    "lib/pq-crypto/bike_r2/secure_decode_portable.c",
    "lib/pq-crypto/bike_r2/utilities.c",
    "lib/pq-crypto/bike_r3/aes_ctr_prf.c",
    "lib/pq-crypto/bike_r3/bike_r3_kem.c",
    "lib/pq-crypto/bike_r3/decode.c",
    "lib/pq-crypto/bike_r3/decode_avx2.c",
    "lib/pq-crypto/bike_r3/decode_avx512.c",
    "lib/pq-crypto/bike_r3/decode_portable.c",
    "lib/pq-crypto/bike_r3/error.c",
    "lib/pq-crypto/bike_r3/gf2x_inv.c",
    "lib/pq-crypto/bike_r3/gf2x_ksqr_avx2.c",
    "lib/pq-crypto/bike_r3/gf2x_ksqr_avx512.c",
    "lib/pq-crypto/bike_r3/gf2x_ksqr_portable.c",
    "lib/pq-crypto/bike_r3/gf2x_mul.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_avx2.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_avx512.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_base_pclmul.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_base_portable.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_base_vpclmul.c",
    "lib/pq-crypto/bike_r3/gf2x_mul_portable.c",
    "lib/pq-crypto/bike_r3/sampling.c",
    "lib/pq-crypto/bike_r3/sampling_avx2.c",
    "lib/pq-crypto/bike_r3/sampling_avx512.c",
    "lib/pq-crypto/bike_r3/sampling_portable.c",
    "lib/pq-crypto/bike_r3/utilities.c",
    "lib/pq-crypto/kyber_90s_r2/aes256ctr.c",
    "lib/pq-crypto/kyber_90s_r2/aes_c.c",
    "lib/pq-crypto/kyber_90s_r2/cbd.c",
    "lib/pq-crypto/kyber_90s_r2/indcpa.c",
    "lib/pq-crypto/kyber_90s_r2/kyber_90s_r2_kem.c",
    "lib/pq-crypto/kyber_90s_r2/ntt.c",
    "lib/pq-crypto/kyber_90s_r2/poly.c",
    "lib/pq-crypto/kyber_90s_r2/polyvec.c",
    "lib/pq-crypto/kyber_90s_r2/reduce.c",
    "lib/pq-crypto/kyber_90s_r2/sha2_c.c",
    "lib/pq-crypto/kyber_90s_r2/verify.c",
    "lib/pq-crypto/kyber_r2/cbd.c",
    "lib/pq-crypto/kyber_r2/fips202_kyber_r2.c",
    "lib/pq-crypto/kyber_r2/indcpa.c",
    "lib/pq-crypto/kyber_r2/kyber_r2_kem.c",
    "lib/pq-crypto/kyber_r2/ntt.c",
    "lib/pq-crypto/kyber_r2/poly.c",
    "lib/pq-crypto/kyber_r2/polyvec.c",
    "lib/pq-crypto/kyber_r2/reduce.c",
    "lib/pq-crypto/kyber_r2/symmetric-fips202.c",
    "lib/pq-crypto/kyber_r2/verify.c",
    "lib/pq-crypto/kyber_r3/KeccakP-1600-times4-SIMD256_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_cbd.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_cbd_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_consts_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_fips202.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_fips202x4_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_indcpa.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_indcpa_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_kem.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_ntt.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_poly.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_poly_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_polyvec.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_polyvec_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_reduce.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_rejsample_avx2.c",
    "lib/pq-crypto/kyber_r3/kyber512r3_symmetric-shake.c",
    "lib/pq-crypto/s2n_pq.c",
    "lib/pq-crypto/s2n_pq_random.c",
    "lib/pq-crypto/sike_r1/P503_r1.c",
    "lib/pq-crypto/sike_r1/ec_isogeny_r1.c",
    "lib/pq-crypto/sike_r1/fips202_r1.c",
    "lib/pq-crypto/sike_r1/fp_generic_r1.c",
    "lib/pq-crypto/sike_r1/fpx_r1.c",
    "lib/pq-crypto/sike_r1/sidh_r1.c",
    "lib/pq-crypto/sike_r1/sike_r1_kem.c",
    "lib/pq-crypto/sike_r3/sikep434r3.c",
    "lib/pq-crypto/sike_r3/sikep434r3_ec_isogeny.c",
    "lib/pq-crypto/sike_r3/sikep434r3_fips202.c",
    "lib/pq-crypto/sike_r3/sikep434r3_fp.c",
    "lib/pq-crypto/sike_r3/sikep434r3_fpx.c",
    "lib/pq-crypto/sike_r3/sikep434r3_kem.c",
    "lib/pq-crypto/sike_r3/sikep434r3_sidh.c",
    "lib/stuffer/s2n_stuffer.c",
    "lib/stuffer/s2n_stuffer_base64.c",
    "lib/stuffer/s2n_stuffer_file.c",
    "lib/stuffer/s2n_stuffer_network_order.c",
    "lib/stuffer/s2n_stuffer_pem.c",
    "lib/stuffer/s2n_stuffer_text.c",
    "lib/tls/extensions/s2n_client_alpn.c",
    "lib/tls/extensions/s2n_client_early_data_indication.c",
    "lib/tls/extensions/s2n_client_ems.c",
    "lib/tls/extensions/s2n_client_key_share.c",
    "lib/tls/extensions/s2n_client_max_frag_len.c",
    "lib/tls/extensions/s2n_client_pq_kem.c",
    "lib/tls/extensions/s2n_client_psk.c",
    "lib/tls/extensions/s2n_client_renegotiation_info.c",
    "lib/tls/extensions/s2n_client_sct_list.c",
    "lib/tls/extensions/s2n_client_server_name.c",
    "lib/tls/extensions/s2n_client_session_ticket.c",
    "lib/tls/extensions/s2n_client_signature_algorithms.c",
    "lib/tls/extensions/s2n_client_status_request.c",
    "lib/tls/extensions/s2n_client_supported_groups.c",
    "lib/tls/extensions/s2n_client_supported_versions.c",
    "lib/tls/extensions/s2n_cookie.c",
    "lib/tls/extensions/s2n_ec_point_format.c",
    "lib/tls/extensions/s2n_extension_list.c",
    "lib/tls/extensions/s2n_extension_type.c",
    "lib/tls/extensions/s2n_extension_type_lists.c",
    "lib/tls/extensions/s2n_key_share.c",
    "lib/tls/extensions/s2n_nst_early_data_indication.c",
    "lib/tls/extensions/s2n_psk_key_exchange_modes.c",
    "lib/tls/extensions/s2n_quic_transport_params.c",
    "lib/tls/extensions/s2n_server_alpn.c",
    "lib/tls/extensions/s2n_server_certificate_status.c",
    "lib/tls/extensions/s2n_server_early_data_indication.c",
    "lib/tls/extensions/s2n_server_ems.c",
    "lib/tls/extensions/s2n_server_key_share.c",
    "lib/tls/extensions/s2n_server_max_fragment_length.c",
    "lib/tls/extensions/s2n_server_psk.c",
    "lib/tls/extensions/s2n_server_renegotiation_info.c",
    "lib/tls/extensions/s2n_server_sct_list.c",
    "lib/tls/extensions/s2n_server_server_name.c",
    "lib/tls/extensions/s2n_server_session_ticket.c",
    "lib/tls/extensions/s2n_server_signature_algorithms.c",
    "lib/tls/extensions/s2n_server_status_request.c",
    "lib/tls/extensions/s2n_server_supported_versions.c",
    "lib/tls/extensions/s2n_supported_versions.c",
    "lib/tls/s2n_aead.c",
    "lib/tls/s2n_alerts.c",
    "lib/tls/s2n_async_pkey.c",
    "lib/tls/s2n_auth_selection.c",
    "lib/tls/s2n_cbc.c",
    "lib/tls/s2n_change_cipher_spec.c",
    "lib/tls/s2n_cipher_preferences.c",
    "lib/tls/s2n_cipher_suites.c",
    "lib/tls/s2n_client_cert.c",
    "lib/tls/s2n_client_cert_verify.c",
    "lib/tls/s2n_client_finished.c",
    "lib/tls/s2n_client_hello.c",
    "lib/tls/s2n_client_hello_request.c",
    "lib/tls/s2n_client_key_exchange.c",
    "lib/tls/s2n_config.c",
    "lib/tls/s2n_connection.c",
    "lib/tls/s2n_connection_evp_digests.c",
    "lib/tls/s2n_early_data.c",
    "lib/tls/s2n_early_data_io.c",
    "lib/tls/s2n_ecc_preferences.c",
    "lib/tls/s2n_encrypted_extensions.c",
    "lib/tls/s2n_establish_session.c",
    "lib/tls/s2n_handshake.c",
    "lib/tls/s2n_handshake_hashes.c",
    "lib/tls/s2n_handshake_io.c",
    "lib/tls/s2n_handshake_transcript.c",
    "lib/tls/s2n_handshake_type.c",
    "lib/tls/s2n_kem.c",
    "lib/tls/s2n_kem_preferences.c",
    "lib/tls/s2n_kex.c",
    "lib/tls/s2n_key_log.c",
    "lib/tls/s2n_key_update.c",
    "lib/tls/s2n_ocsp_stapling.c",
    "lib/tls/s2n_post_handshake.c",
    "lib/tls/s2n_prf.c",
    "lib/tls/s2n_protocol_preferences.c",
    "lib/tls/s2n_psk.c",
    "lib/tls/s2n_quic_support.c",
    "lib/tls/s2n_record_read.c",
    "lib/tls/s2n_record_read_aead.c",
    "lib/tls/s2n_record_read_cbc.c",
    "lib/tls/s2n_record_read_composite.c",
    "lib/tls/s2n_record_read_stream.c",
    "lib/tls/s2n_record_write.c",
    "lib/tls/s2n_recv.c",
    "lib/tls/s2n_resume.c",
    "lib/tls/s2n_security_policies.c",
    "lib/tls/s2n_send.c",
    "lib/tls/s2n_server_cert.c",
    "lib/tls/s2n_server_cert_request.c",
    "lib/tls/s2n_server_done.c",
    "lib/tls/s2n_server_extensions.c",
    "lib/tls/s2n_server_finished.c",
    "lib/tls/s2n_server_hello.c",
    "lib/tls/s2n_server_hello_retry.c",
    "lib/tls/s2n_server_key_exchange.c",
    "lib/tls/s2n_server_new_session_ticket.c",
    "lib/tls/s2n_shutdown.c",
    "lib/tls/s2n_signature_algorithms.c",
    "lib/tls/s2n_signature_scheme.c",
    "lib/tls/s2n_tls.c",
    "lib/tls/s2n_tls13.c",
    "lib/tls/s2n_tls13_certificate_verify.c",
    "lib/tls/s2n_tls13_handshake.c",
    "lib/tls/s2n_tls13_key_schedule.c",
    "lib/tls/s2n_tls13_secrets.c",
    "lib/tls/s2n_x509_validator.c",
    "lib/utils/s2n_array.c",
    "lib/utils/s2n_asn1_time.c",
    "lib/utils/s2n_blob.c",
    "lib/utils/s2n_ensure.c",
    "lib/utils/s2n_fork_detection.c",
    "lib/utils/s2n_init.c",
    "lib/utils/s2n_map.c",
    "lib/utils/s2n_mem.c",
    "lib/utils/s2n_random.c",
    "lib/utils/s2n_result.c",
    "lib/utils/s2n_rfc5952.c",
    "lib/utils/s2n_safety.c",
    "lib/utils/s2n_set.c",
    "lib/utils/s2n_socket.c",
    "lib/utils/s2n_timer.c",
]
